
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.27.0',
    'branch_nick': 'master',
    'revision_id': '1f3f9879015e3115962c088b62061da2e6fd5387',
    'revno': 11142
}
