# -*- coding: utf-8 -*-
# Copyright 2020 CERN
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Authors:
# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
# - Martin Barisits <martin.barisits@cern.ch>, 2020
# - Matt Snyder <msnyder@bnl.gov>, 2021
# - Cedric Serfon <cedric.serfon@cern.ch>, 2021
# - Joaquin Bogado <joaquinbogado@gmail.com>, 2021
# - Ilija Vukotic <ivukotic@uchicago.edu>, 2021

ALEMBIC_REVISION = '9a45bc4ea66d'  # the current alembic head revision
